========================
 Running Tests Remotely
========================

The Avocado results are easily copyable between machines, so you can
manually run your jobs on various machines and copy the results dir
to your main machines while still being able to re-run/diff/... them.
Anyway if you want even smoother remote execution, you can use our
:ref:`remote-runner-plugins` optional plugins to run jobs on a remote
systems (machine, container, ...) reporting the results locally.
